just_results library

Support for doing something awesome.

More dartdocs go here.

Classes

Result<T, E>
The Result class This class helps us to return errors as a value, making it easier to deal with error values without having to rely on exceptions

Extensions

FutureExt on Future<T>
FutureResultExt on Future<Result<T, E>>
An extension on Future<Result> that makes using Future Results easier to use
MapResult on Map<K, V>
An extension on Map that allows us to get a value for some key wrapped in a Result

Typedefs

FResult<T, E> = Future<Result<T, E>>
A Future Result
FVal<T> = FResult<T, String>
A Future Result where error is String
Val<T> = Result<T, String>
A Result where error is String