just_results library
Support for doing something awesome.
More dartdocs go here.
Classes
-
Result<
T, E> - The Result class This class helps us to return errors as a value, making it easier to deal with error values without having to rely on exceptions